@@ -1,7 +1,9 @@
 import argparse
+from typing import Optional
 
+EXPORT_FORMATS = ["html", "html-standalone", "rst", "excel", "reqif-sdoc"]
 
-EXPORT_FORMATS = ["html", "html-standalone", "rst", "excel"]
+REQIF_PARSERS = ["sdoc", "fm-studio"]
 
 
 def _check_formats(formats):
@@ -9,9 +11,8 @@ def _check_formats(formats):
     for fmt in formats_array:
         if fmt in EXPORT_FORMATS:
             continue
-        message = "invalid choice: '{}' (choose from {})".format(
-            fmt, ", ".join(map(lambda f: f"'{f}'", EXPORT_FORMATS))
-        )
+        export_formats = ", ".join(map(lambda f: f"'{f}'", EXPORT_FORMATS))
+        message = f"invalid choice: '{fmt}' (choose from {export_formats})"
         raise argparse.ArgumentTypeError(message)
     return formats_array
 
@@ -34,22 +35,29 @@ def cli_args_parser() -> argparse.ArgumentParser:
     #         assert 0
     #         exit(0)
 
+    def formatter(prog):
+        return argparse.RawTextHelpFormatter(
+            prog, indent_increment=2, max_help_position=4, width=80
+        )
+
     # https://stackoverflow.com/a/19476216/598057
     main_parser = argparse.ArgumentParser()
+    main_parser.formatter_class = formatter
 
     command_subparsers = main_parser.add_subparsers(
         title="command", dest="command"
     )
     command_subparsers.required = True
 
+    # Command: Export
     command_parser_export = command_subparsers.add_parser(
         "export",
         help="Export document tree.",
-        parents=[],
         description=(
             "Export command: "
             "input SDoc documents are generated into HTML and other formats."
         ),
+        formatter_class=formatter,
     )
     command_parser_export.add_argument(
         "input_paths",
@@ -86,7 +94,7 @@ def cli_args_parser() -> argparse.ArgumentParser:
     command_parser_export.add_argument(
         "--enable-mathjax",
         action="store_true",
-        help=("Enables Mathjax support (only HTML export)."),
+        help="Enables Mathjax support (only HTML export).",
     )
     command_parser_export.add_argument(
         "--experimental-enable-file-traceability",
@@ -98,8 +106,57 @@ def cli_args_parser() -> argparse.ArgumentParser:
         ),
     )
 
+    # Command: Import
+    command_parser_import = command_subparsers.add_parser(
+        "import",
+        help="Create StrictDoc files from other formats.",
+        description="Create StrictDoc files from other formats.",
+        formatter_class=formatter,
+    )
+    command_parser_import_subparsers = command_parser_import.add_subparsers(
+        title="import_format", dest="import_format"
+    )
+    command_parser_import_subparsers.required = True
+
+    command_parser_import_reqif = command_parser_import_subparsers.add_parser(
+        "reqif",
+        help="Create StrictDoc file from ReqIF document.",
+        description="Create StrictDoc file from ReqIF document.",
+        formatter_class=formatter,
+    )
+
+    def check_reqif_parser(parser):
+        if parser not in REQIF_PARSERS:
+            message = (
+                f"invalid choice: '{parser}' (choose from {REQIF_PARSERS})"
+            )
+            raise argparse.ArgumentTypeError(message)
+        return parser
+
+    command_parser_import_reqif.add_argument(
+        "parser",
+        type=check_reqif_parser,
+        help=(
+            "An argument that selects the ReqIF parser. "
+            f"Possible values: {{{', '.join(REQIF_PARSERS)}}}"
+        ),
+    )
+    command_parser_import_reqif.add_argument(
+        "input_path",
+        type=str,
+        help="Path to the input ReqIF file.",
+    )
+    command_parser_import_reqif.add_argument(
+        "output_path",
+        type=str,
+        help="Path to the output SDoc file.",
+    )
+
+    # Command: Passthrough
     command_parser_passthrough = command_subparsers.add_parser(
-        "passthrough", help="Export document tree.", parents=[]
+        "passthrough",
+        help="Read an SDoc file, then output it again. (used for testing)",
+        formatter_class=formatter,
     )
     command_parser_passthrough.add_argument(
         "input_file", type=str, help="Path to the input SDoc file"
@@ -109,17 +166,33 @@ def cli_args_parser() -> argparse.ArgumentParser:
         "--output-file", type=str, help="Path to the output SDoc file"
     )
 
+    # Command: Dump Grammar
+    command_parser_dump_grammar = command_subparsers.add_parser(
+        "dump-grammar",
+        help="Dump the SDoc grammar to a .tx file.",
+        formatter_class=formatter,
+    )
+    command_parser_dump_grammar.add_argument(
+        "output_file", type=str, help="Path to the output .tx file"
+    )
     return main_parser
 
 
+class ImportCommandConfig:
+    def __init__(self, input_path, output_path, parser):
+        self.input_path = input_path
+        self.output_path = output_path
+        self.parser = parser
+
+
 class PassthroughCommandConfig:
     def __init__(self, input_file, output_file):
         self.input_file = input_file
         self.output_file = output_file
 
 
-class ExportCommandConfig:
-    def __init__(
+class ExportCommandConfig:  # pylint: disable=too-many-instance-attributes
+    def __init__(  # pylint: disable=too-many-arguments
         self,
         strictdoc_root_path,
         input_paths,
@@ -133,7 +206,7 @@ class ExportCommandConfig:
     ):
         self.strictdoc_root_path = strictdoc_root_path
         self.input_paths = input_paths
-        self.output_dir = output_dir
+        self.output_dir: Optional[str] = output_dir
         self.project_title = project_title
         self.formats = formats
         self.fields = fields
@@ -144,6 +217,11 @@ class ExportCommandConfig:
         )
 
 
+class DumpGrammarCommandConfig:
+    def __init__(self, output_file):
+        self.output_file = output_file
+
+
 class SDocArgsParser:
     def __init__(self, args):
         self.args = args
@@ -152,15 +230,23 @@ class SDocArgsParser:
     def is_passthrough_command(self):
         return self.args.command == "passthrough"
 
+    @property
+    def is_export_command(self):
+        return self.args.command == "export"
+
+    @property
+    def is_import_command(self):
+        return self.args.command == "import"
+
+    @property
+    def is_dump_grammar_command(self):
+        return self.args.command == "dump-grammar"
+
     def get_passthrough_config(self) -> PassthroughCommandConfig:
         return PassthroughCommandConfig(
             self.args.input_file, self.args.output_file
         )
 
-    @property
-    def is_export_command(self):
-        return self.args.command == "export"
-
     def get_export_config(self, strictdoc_root_path) -> ExportCommandConfig:
         project_title = (
             self.args.project_title
@@ -179,6 +265,14 @@ class SDocArgsParser:
             self.args.experimental_enable_file_traceability,
         )
 
+    def get_import_config(self, _) -> ImportCommandConfig:
+        return ImportCommandConfig(
+            self.args.input_path, self.args.output_path, self.args.parser
+        )
+
+    def get_dump_grammar_config(self) -> DumpGrammarCommandConfig:
+        return DumpGrammarCommandConfig(output_file=self.args.output_file)
+
 
 def create_sdoc_args_parser(testing_args=None) -> SDocArgsParser:
     args = testing_args
