@@ -1,8 +1,10 @@
 import glob
 import os
+import sys
 from pathlib import Path
+from typing import List, Iterator
 
-from strictdoc.backend.dsl.errors.document_tree_error import DocumentTreeError
+from strictdoc.backend.sdoc.errors.document_tree_error import DocumentTreeError
 from strictdoc.backend.source_file_syntax.reader import (
     SourceFileTraceabilityReader,
 )
@@ -20,6 +22,7 @@ from strictdoc.export.html.html_generator import HTMLGenerator
 from strictdoc.export.rst.document_rst_generator import DocumentRSTGenerator
 from strictdoc.helpers.file_modification_time import get_file_modification_time
 from strictdoc.helpers.timing import timing_decorator
+from strictdoc.backend.reqif.reqif_export import ReqIFExport
 
 
 class ExportAction:
@@ -28,13 +31,13 @@ class ExportAction:
     def export(config: ExportCommandConfig, parallelizer):
         assert parallelizer
         cwd = os.getcwd()
-        strict_own_files = glob.iglob(
-            "{}/strictdoc/**/*".format(config.strictdoc_root_path),
+        strict_own_files_unfiltered: Iterator[str] = glob.iglob(
+            f"{config.strictdoc_root_path}/strictdoc/**/*",
             recursive=True,
         )
-        strict_own_files = [
+        strict_own_files: List[str] = [
             f
-            for f in strict_own_files
+            for f in strict_own_files_unfiltered
             if f.endswith(".html") or f.endswith(".py")
         ]
         latest_strictdoc_own_file = max(strict_own_files, key=os.path.getctime)
@@ -52,7 +55,7 @@ class ExportAction:
         if not os.path.isabs(output_dir):
             output_dir = os.path.join(cwd, output_dir)
 
-        output_html_root = "{}/html".format(output_dir)
+        output_html_root = os.path.join(output_dir, "html")
 
         document_tree, asset_dirs = DocumentFinder.find_sdoc_content(
             path_to_single_file_or_doc_root, output_html_root, parallelizer
@@ -64,7 +67,7 @@ class ExportAction:
             )
         except DocumentTreeError as exc:
             print(exc.to_print_message())
-            exit(1)
+            sys.exit(1)
 
         if config.experimental_enable_file_traceability:
             source_tree: SourceTree = SourceFilesFinder.find_source_files(
@@ -73,6 +76,14 @@ class ExportAction:
             source_files = source_tree.source_files
             source_file: SourceFile
             for source_file in source_files:
+                is_source_file_referenced = (
+                    traceability_index.has_source_file_reqs(
+                        source_file.in_doctree_source_file_rel_path
+                    )
+                )
+                if not is_source_file_referenced:
+                    continue
+                source_file.is_referenced = True
                 traceability_reader = SourceFileTraceabilityReader()
                 traceability_info = traceability_reader.read_from_file(
                     source_file.full_path
@@ -97,17 +108,24 @@ class ExportAction:
             )
 
         if "rst" in config.formats:
-            output_rst_root = "{}/rst".format(output_dir)
+            output_rst_root = os.path.join(output_dir, "rst")
             Path(output_rst_root).mkdir(parents=True, exist_ok=True)
             DocumentRSTGenerator.export_tree(
                 document_tree, traceability_index, output_rst_root
             )
 
         if "excel" in config.formats:
-            output_excel_root = "{}/excel".format(output_dir)
+            output_excel_root = f"{output_dir}/excel"
             ExcelGenerator.export_tree(
                 document_tree,
                 traceability_index,
                 output_excel_root,
                 config.fields,
             )
+
+        if "reqif-sdoc" in config.formats:
+            output_reqif_root = f"{output_dir}/reqif"
+            ReqIFExport.export(
+                document_tree,
+                output_reqif_root,
+            )
