@@ -1,13 +1,14 @@
 import os
 import sys
 
-from strictdoc.backend.dsl.reader import SDReader
-from strictdoc.backend.dsl.writer import SDWriter
+from strictdoc.backend.sdoc.reader import SDReader
+from strictdoc.backend.sdoc.writer import SDWriter
 from strictdoc.cli.cli_arg_parser import PassthroughCommandConfig
 
 
 class PassthroughAction:
-    def passthrough(self, config: PassthroughCommandConfig):
+    @staticmethod
+    def passthrough(config: PassthroughCommandConfig):
         if not os.path.isfile(config.input_file):
             sys.stdout.flush()
             err = (
@@ -15,11 +16,11 @@ class PassthroughAction:
                 "No such file or directory"
             )
             print(err)
-            exit(1)
+            sys.exit(1)
 
         document = SDReader().read_from_file(config.input_file)
 
         writer = SDWriter()
         output = writer.write(document)
-        with open(config.output_file, "w") as file:
+        with open(config.output_file, "w", encoding="utf8") as file:
             file.write(output)
