@@ -1,8 +1,8 @@
 import os
 import sys
 
-from strictdoc.backend.dsl.models.document import Document
-from strictdoc.backend.dsl.reader import SDReader
+from strictdoc.backend.sdoc.models.document import Document
+from strictdoc.backend.sdoc.reader import SDReader
 from strictdoc.core.document_meta import DocumentMeta
 from strictdoc.core.document_tree import DocumentTree
 from strictdoc.core.file_tree import (
@@ -16,7 +16,7 @@ from strictdoc.helpers.timing import measure_performance, timing_decorator
 
 class DocumentFinder:
     @staticmethod
-    @timing_decorator("Find")
+    @timing_decorator("Find and read SDoc files")
     def find_sdoc_content(
         paths_to_files_or_docs, output_root_html, parallelizer
     ):
@@ -46,7 +46,7 @@ class DocumentFinder:
         doc_full_path = doc_file.get_full_path()
 
         with measure_performance(
-            "Reading SDOC: {}".format(os.path.basename(doc_full_path))
+            f"Reading SDOC: {os.path.basename(doc_full_path)}"
         ):
             reader = SDReader()
             document = reader.read_from_file(doc_full_path)
@@ -84,7 +84,7 @@ class DocumentFinder:
             doc_relative_path_folder = os.path.dirname(doc_relative_path)
 
             output_document_dir_rel_path = (
-                "{}/{}".format(file_tree_mount_folder, doc_relative_path_folder)
+                f"{file_tree_mount_folder}/{doc_relative_path_folder}"
                 if doc_relative_path_folder
                 else file_tree_mount_folder
             )
@@ -92,8 +92,8 @@ class DocumentFinder:
             document_filename = os.path.basename(input_doc_full_path)
             document_filename_base = os.path.splitext(document_filename)[0]
 
-            output_document_dir_full_path = "{}/{}".format(
-                output_root_html, output_document_dir_rel_path
+            output_document_dir_full_path = (
+                f"{output_root_html}/{output_document_dir_rel_path}"
             )
 
             document_meta = DocumentMeta(
