@@ -6,8 +6,8 @@ import xlsxwriter
 from xlsxwriter.workbook import Workbook
 from xlsxwriter.worksheet import Worksheet
 
-from strictdoc.backend.dsl.models.document import Document
-from strictdoc.backend.dsl.models.requirement import Requirement
+from strictdoc.backend.sdoc.models.document import Document
+from strictdoc.backend.sdoc.models.requirement import Requirement
 from strictdoc.core.document_tree import DocumentTree
 
 EXCEL_SHEET_NAME = "Requirements"
@@ -52,9 +52,13 @@ class ExcelGenerator:
 
         document: Document
         for document in document_tree.document_list:
-            document_out_file = "{}/{}.xlsx".format(
-                output_excel_root, document.meta.document_filename_base
+            document_out_file_name = (
+                f"{document.meta.document_filename_base}.xlsx"
             )
+            document_out_file = os.path.join(
+                output_excel_root, document_out_file_name
+            )
+
             ExcelGenerator._export_single_document(
                 document, traceability_index, document_out_file, fields
             )
@@ -115,9 +119,9 @@ class ExcelGenerator:
                         if value and len(value) > columns[field][MAX_WIDTH_KEY]:
                             columns[field][MAX_WIDTH_KEY] = len(value)
                     elif len(node.special_fields):
-                        for sf in node.special_fields:
-                            if sf.field_name.lower() == field:
-                                value = sf.field_value
+                        for special_field in node.special_fields:
+                            if special_field.field_name.lower() == field:
+                                value = special_field.field_value
                                 worksheet.write(row, idx, value)
                                 if (
                                     value
@@ -168,9 +172,9 @@ class ExcelGenerator:
     def _init_columns_width(fields: List[str]):
         columns = {}
 
-        for f in fields:
-            columns[f] = {}
-            columns[f][MAX_WIDTH_KEY] = len(f) + HEADER_MARGIN
+        for field in fields:
+            columns[field] = {}
+            columns[field][MAX_WIDTH_KEY] = len(field) + HEADER_MARGIN
         return columns
 
     @staticmethod
@@ -190,7 +194,7 @@ class ExcelGenerator:
     def _init_headers(fields: List[str]) -> List:
         headers: List = []
 
-        for f in fields:
-            headers.append({"header": f.upper()})
+        for field in fields:
+            headers.append({"header": field.upper()})
 
         return headers
