@@ -1,7 +1,7 @@
 import os
 from pathlib import Path
 
-from strictdoc.backend.dsl.models.document import Document
+from strictdoc.backend.sdoc.models.document import Document
 from strictdoc.core.document_tree import DocumentTree
 from strictdoc.export.rst.writer import RSTWriter
 
@@ -32,7 +32,7 @@ class DocumentRSTGenerator:
             document_out_file = f"{document.meta.document_filename_base}.rst"
             output_path = os.path.join(output_folder, document_out_file)
 
-            with open(output_path, "w") as file:
+            with open(output_path, "w", encoding="utf8") as file:
                 file.write(document_content)
 
     @staticmethod
