@@ -1,11 +1,17 @@
 import io
+import sys
 
 from docutils.core import publish_parts
 
 
 class RstToHtmlFragmentWriter:
+    cache = {}
+
     @staticmethod
     def write(rst_fragment):
+        if rst_fragment in RstToHtmlFragmentWriter.cache:
+            return RstToHtmlFragmentWriter.cache[rst_fragment]
+
         # How do I convert a docutils document tree into an HTML string?
         # https://stackoverflow.com/a/32168938/598057
         # Use a io.StringIO as the warning stream to prevent warnings from
@@ -25,9 +31,12 @@ class RstToHtmlFragmentWriter:
             print("RST fragment: >>>")
             print(rst_fragment)
             print("<<<")
-            exit(1)
+            sys.exit(1)
 
         html = output["html_body"]
+
+        RstToHtmlFragmentWriter.cache[rst_fragment] = html
+
         return html
 
     @staticmethod
