@@ -1,9 +1,9 @@
 from enum import Enum
 
-from strictdoc.backend.dsl.models.inline_link import InlineLink
-from strictdoc.backend.dsl.models.requirement import Requirement
-from strictdoc.backend.dsl.models.section import FreeText, Section
-from strictdoc.backend.dsl.models.special_field import SpecialField
+from strictdoc.backend.sdoc.models.inline_link import InlineLink
+from strictdoc.backend.sdoc.models.requirement import Requirement
+from strictdoc.backend.sdoc.models.section import FreeText, Section
+from strictdoc.backend.sdoc.models.special_field import SpecialField
 from strictdoc.core.document_iterator import DocumentCachingIterator
 from strictdoc.core.traceability_index import TraceabilityIndex
 
@@ -41,7 +41,8 @@ class RSTWriter:
 
         return output.lstrip()
 
-    def _print_rst_header(self, string, level):
+    @staticmethod
+    def _print_rst_header(string, level):
         chars = {
             0: "$",
             1: "=",
@@ -65,7 +66,7 @@ class RSTWriter:
 
         meta_table_started = False
         if section_content.uid:
-            output += ".. _{}:".format(section_content.uid)
+            output += f".. _{section_content.uid}:"
             output += "\n\n"
             output += self._print_rst_header(
                 section_content.title, section_content.ng_level
@@ -123,8 +124,8 @@ class RSTWriter:
             output += "**Parents:**"
             output += "\n\n"
             for reference in requirement_references:
-                output += "- ``[{}]`` ".format(reference.path)
-                output += ":ref:`{}`".format(reference.path)
+                output += f"- ``[{reference.path}]`` "
+                output += f":ref:`{reference.path}`"
                 output += "\n"
             output += "\n"
 
@@ -134,8 +135,8 @@ class RSTWriter:
             for child_requirement in self.index.get_children_requirements(
                 section_content
             ):
-                output += "- ``[{}]`` ".format(child_requirement.uid)
-                output += ":ref:`{}`".format(child_requirement.uid)
+                output += f"- ``[{child_requirement.uid}]`` "
+                output += f":ref:`{child_requirement.uid}`"
                 output += "\n"
             output += "\n"
 
@@ -143,7 +144,7 @@ class RSTWriter:
 
     def _print_free_text(self, free_text):
         assert isinstance(free_text, FreeText)
-        if not len(free_text.parts):
+        if len(free_text.parts) == 0:
             return ""
         output = ""
         for part in free_text.parts:
